@@ -6,12 +6,11 @@ pushd ..
 ABS_PATH=$(pwd)
 popd
 
-# Assume Ubuntu: install a recent version of clang and libomp
-echo "deb http://apt.llvm.org/xenial/ llvm-toolchain-xenial-8 main" | sudo tee -a /etc/apt/sources.list.d/llvm.list
-echo "deb-src http://apt.llvm.org/xenial/ llvm-toolchain-xenial-8 main" | sudo tee -a /etc/apt/sources.list.d/llvm.list
-wget -O - https://apt.llvm.org/llvm-snapshot.gpg.key | sudo apt-key add -
-sudo apt update
-sudo apt install clang-8 libomp-8-dev
+# Install a recent version of clang and libomp
+wget https://apt.llvm.org/llvm.sh
+chmod +x llvm.sh
+sudo ./llvm.sh 10
+sudo apt-get install libomp-dev
 
 # create conda env
 conda create -n $VIRTUALENV -q --yes python=$VERSION_PYTHON pip cython
@@ -36,6 +35,7 @@ popd
 # build & install numpy
 git clone https://github.com/numpy/numpy.git
 pushd numpy
+git submodule update --init
 echo "[blis]
 libraries = blis
 library_dirs = $ABS_PATH/BLIS_install/lib
@@ -52,7 +52,7 @@ CFLAGS=-I$ABS_PATH/BLIS_install/include/blis LDFLAGS=-L$ABS_PATH/BLIS_install/li
     bash ./continuous_integration/build_test_ext.sh
 
 python --version
-python -c "import numpy; print('numpy %s' % numpy.__version__)" || echo "no numpy"
-python -c "import scipy; print('scipy %s' % scipy.__version__)" || echo "no scipy"
+python -c "import numpy; print(f'numpy {numpy.__version__}')" || echo "no numpy"
+python -c "import scipy; print(f'scipy {scipy.__version__}')" || echo "no scipy"
 
 python -m flit install --symlink
